//----------------------------------------------------------------------
// concord.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const fs = require('fs');

//----------------------------------------------------------------------

function createConcordance(data) {
   let lowercaseData = data.toLowerCase();
   let words = lowercaseData.match(/[a-z]+/g);
   if (words === null)
      words = [];

   let concordance = {};
   for (let word of words)
      if (word in concordance)
         concordance[word]++;
      else
         concordance[word] = 1;
   return concordance;
}

//----------------------------------------------------------------------

function writeConcordance(concordance) {
   for (let word in concordance)
      process.stdout.write(word + ': ' + concordance[word] + '\n');
}

//----------------------------------------------------------------------

function main() {
   if (process.argv.length !== 3) {
      process.stderr.write('Usage: ' + process.argv[0] + ' ' +
         process.argv[1] + ' infile\n');
      process.exit(1);
   }

   let fileName = process.argv[2];

   try {
      let data = fs.readFileSync(fileName, 'UTF-8');
      let concordance = createConcordance(data);
      writeConcordance(concordance);
   }
   catch (err) {
       process.stderr.write(err + '\n');
   }
}

if (require.main === module)
   main();
