//----------------------------------------------------------------------
// fraction5.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';

const euclid = require('./euclid.js');

class Fraction {
   constructor(num=0, den=1) {
      if (arguments.length > 2)
         throw new Error('Too many arguments');

      if (den === 0)
         throw new Error('Denominator cannot be zero');

      this._num = num;
      this._den = den;

      if (this._den < 0) {
         this._num *= -1;
         this._den *= -1;
      }
      if (this._num === 0)
         this._den = 1;
      else {
         let gcden = euclid.gcd(this._num, this._den);
         this._num /= gcden;
         this._den /= gcden;
      }
   }

   toString() {
      return String(this._num) + '/' + String(this._den);
   }

   compareTo(other) {
      if ((this._num * other._den) < (other._num * this._den))
         return -1;
      if ((this._num * other._den) > (other._num * this._den))
         return 1;
      return 0;
   }

   negate() {
      return new Fraction(-this._num, this._den);
   }

   add(other) {
      let newNum = (this._num * other._den) + (other._num * this._den);
      let newDen = this._den * other._den;
      return new Fraction(newNum, newDen);
   }

   subtract(other) {
      let newNum = (this._num * other._den) - (other._num * this._den);
      let newDen = this._den * other._den;
      return new Fraction(newNum, newDen);
   }

   multiply(other) {
      let newNum = this._num * other._num;
      let newDen = this._den * other._den;
      return new Fraction(newNum, newDen);
   }

   divide(other) {
      let newNum = this._num * other._den;
      let newDen = this._den * other._num;
      return new Fraction(newNum, newDen);
   }
}

module.exports = { Fraction };
