//----------------------------------------------------------------------
// linesortcallback.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';
const fs = require('fs');

//----------------------------------------------------------------------

function splitIntoLines(str) {
   let lines = [];
   let line = '';
   for (let c of str) {
      if (c === '\n') { lines.push(line); line = ''; }
      else line += c;
   }
   if (line !== '') lines.push(line);
   return lines;
}

//----------------------------------------------------------------------

function reportError(err) {
   process.stderr.write(err.message + '\n');
}

//----------------------------------------------------------------------

function writeLines(lines) {
   for (let line of lines)
      process.stdout.write(line + '\n');
}

//----------------------------------------------------------------------

function sortWriteLines(err, data) {
   if (err)
      reportError(err);
   else {
      let lines = splitIntoLines(data);
      lines.sort();
      writeLines(lines);
   }
}

//----------------------------------------------------------------------

function main() {
   if (process.argv.length !== 3) {
      process.stderr.write('Usage: ' + process.argv[0] + ' ' +
         process.argv[1] + ' infile\n');
      process.exit(1);
   }
   let fileName = process.argv[2];
   fs.readFile(fileName, 'UTF-8', sortWriteLines);
   process.stderr.write('Doing other work\n');
}

if (require.main === module)
   main();
