//----------------------------------------------------------------------
// linesortpromises.js
// Author: Bob Dondero
//----------------------------------------------------------------------

'use strict';
const fs = require('fs');

//----------------------------------------------------------------------
function splitIntoLines(str) {
   let lines = [];
   let line = '';
   for (let c of str) {
      if (c === '\n') { lines.push(line); line = ''; }
      else line += c;
   }
   if (line !== '') lines.push(line);
   return lines;
}

//----------------------------------------------------------------------
function reportError(err) {
   process.stderr.write(err.message + '\n');
}

//----------------------------------------------------------------------
function writeLines(lines) {
   for (let line of lines)
      process.stdout.write(line + '\n');
}

//----------------------------------------------------------------------
function sortLines(data) {
   let lines = splitIntoLines(data);
   lines.sort();
   return lines;
}

//----------------------------------------------------------------------
function main(argv) {
   if (argv.length !== 3) {
      process.stderr.write(
         'Usage: ' + process.argv[0] + ' ' + process.argv[1] +
         ' infile\n');
      process.exit(1);
   }
   let fileName = process.argv[2];

   // let promise1 = fs.promises.readFile(fileName, 'UTF-8');
   // let promise2 = promise1.then(sortLines);
   // let promise3 = promise2.then(writeLines);
   // promise3.catch(reportError);

   fs.promises.readFile(fileName, 'UTF-8')
      .then(sortLines)
      .then(writeLines)
      .catch(reportError);

   process.stderr.write('Doing other work\n');
}

if (require.main === module)
   main(process.argv);
